@@ -7,6 +7,7 @@ return [
         'Africa/Addis_Ababa' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಆಡಿಸ್ ಅಬಾಬಾ)',
         'Africa/Algiers' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಅಲ್ಜೀರ್ಸ್)',
         'Africa/Asmera' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಅಸ್ಮಾರಾ)',
+        'Africa/Asmara' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಅಸ್ಮಾರಾ)',
         'Africa/Bamako' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಬಮಾಕೊ)',
         'Africa/Bangui' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ (ಬಾಂಗಿ)',
         'Africa/Banjul' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಬಂಜುಲ್)',
@@ -59,13 +60,13 @@ return [
         'America/Anguilla' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಆಂಗ್ವಿಲ್ಲಾ)',
         'America/Antigua' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಆಂಟಿಗುವಾ)',
         'America/Araguaina' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಅರಾಗುಯಾನಾ)',
-        'America/Argentina/La_Rioja' => 'ಅರ್ಜೆಂಟಿನಾ ಸಮಯ (ಲಾ ರಿಯೋಜಾ)',
-        'America/Argentina/Rio_Gallegos' => 'ಅರ್ಜೆಂಟಿನಾ ಸಮಯ (ರಿಯೋ ಗಲ್ಲೆಗೊಸ್)',
-        'America/Argentina/Salta' => 'ಅರ್ಜೆಂಟಿನಾ ಸಮಯ (ಸಾಲ್ಟಾ)',
-        'America/Argentina/San_Juan' => 'ಅರ್ಜೆಂಟಿನಾ ಸಮಯ (ಸ್ಯಾನ್ ಜುವಾನ್)',
-        'America/Argentina/San_Luis' => 'ಅರ್ಜೆಂಟಿನಾ ಸಮಯ (ಸ್ಯಾನ್ ಲೂಯೀಸ್)',
-        'America/Argentina/Tucuman' => 'ಅರ್ಜೆಂಟಿನಾ ಸಮಯ (ಟುಕುಮಾನ್)',
-        'America/Argentina/Ushuaia' => 'ಅರ್ಜೆಂಟಿನಾ ಸಮಯ (ಉಶ್ವಾಯ)',
+        'America/Argentina/La_Rioja' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಲಾ ರಿಯೋಜಾ)',
+        'America/Argentina/Rio_Gallegos' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ರಿಯೋ ಗಲ್ಲೆಗೊಸ್)',
+        'America/Argentina/Salta' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಸಾಲ್ಟಾ)',
+        'America/Argentina/San_Juan' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಸ್ಯಾನ್ ಜುವಾನ್)',
+        'America/Argentina/San_Luis' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಸ್ಯಾನ್ ಲೂಯೀಸ್)',
+        'America/Argentina/Tucuman' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಟುಕುಮಾನ್)',
+        'America/Argentina/Ushuaia' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಉಶ್ವಾಯ)',
         'America/Aruba' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಅರುಬಾ)',
         'America/Asuncion' => 'ಪರಾಗ್ವೇ ಸಮಯ (ಅಸುನ್ಸಿಯಾನ್)',
         'America/Bahia' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಬಹೀಯಾ)',
@@ -77,19 +78,25 @@ return [
         'America/Boa_Vista' => 'ಅಮೆಜಾನ್ ಸಮಯ (ಬೋವಾ ವಿಸ್ಟ)',
         'America/Bogota' => 'ಕೊಲಂಬಿಯಾ ಸಮಯ (ಬೊಗೋಟ)',
         'America/Boise' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಬ್ವಾಸಿ)',
-        'America/Buenos_Aires' => 'ಅರ್ಜೆಂಟಿನಾ ಸಮಯ (ಬ್ಯೂನಸ್ ಐರಿಸ್)',
+        'America/Buenos_Aires' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಬ್ಯೂನಸ್ ಐರಿಸ್)',
+        'America/Argentina/Buenos_Aires' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಬ್ಯೂನಸ್ ಐರಿಸ್)',
         'America/Cambridge_Bay' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಕೇಮ್‌ಬ್ರಿಡ್ಜ್ ಬೇ)',
         'America/Campo_Grande' => 'ಅಮೆಜಾನ್ ಸಮಯ (ಕಾಂಪೊ ಗ್ರಾಂಡೆ)',
         'America/Cancun' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಕ್ಯಾಂಕನ್)',
         'America/Caracas' => 'ವೆನಿಜುವೆಲಾ ಸಮಯ (ಕ್ಯಾರಕಾಸ್)',
-        'America/Catamarca' => 'ಅರ್ಜೆಂಟಿನಾ ಸಮಯ (ಕಟಮಾರ್ಕ)',
+        'America/Catamarca' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಕಟಮಾರ್ಕ)',
+        'America/Argentina/Catamarca' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಕಟಮಾರ್ಕ)',
         'America/Cayenne' => 'ಫ್ರೆಂಚ್ ಗಯಾನಾ ಸಮಯ (ಕೆಯೆನಿ)',
         'America/Cayman' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಕೇಮನ್)',
         'America/Chicago' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಚಿಕಾಗೋ)',
-        'America/Chihuahua' => 'ಮೆಕ್ಸಿಕನ್ ಪೆಸಿಫಿಕ್ ಸಮಯ (ಚಿವಾವ)',
+        'America/Chihuahua' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಚಿವಾವ)',
+        'America/Ciudad_Juarez' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಸಿಯುಡಾಡ್ ವಾರೆಝ್)',
         'America/Coral_Harbour' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಅಟಿಕೊಕಾನ್)',
-        'America/Cordoba' => 'ಅರ್ಜೆಂಟಿನಾ ಸಮಯ (ಕೊರ್ಡೊಬಾ)',
+        'America/Atikokan' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಅಟಿಕೊಕಾನ್)',
+        'America/Cordoba' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಕೊರ್ಡೊಬಾ)',
+        'America/Argentina/Cordoba' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಕೊರ್ಡೊಬಾ)',
         'America/Costa_Rica' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಕೋಸ್ಟಾ ರಿಕಾ)',
+        'America/Coyhaique' => 'ಚಿಲಿ ಸಮಯ (ಕೊಯಯ್ಕಿ)',
         'America/Creston' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಕ್ರೆಸ್ಟನ್)',
         'America/Cuiaba' => 'ಅಮೆಜಾನ್ ಸಮಯ (ಕ್ಯೂಇಬಾ)',
         'America/Curacao' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಕುರಾಕಾವ್)',
@@ -105,7 +112,8 @@ return [
         'America/Fort_Nelson' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಫೋರ್ಟ್ ನೆಲ್ಸನ್)',
         'America/Fortaleza' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಫೊರ್ಟಲೆಜಾ)',
         'America/Glace_Bay' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಗ್ಲೇಸ್ ಬೇ)',
-        'America/Godthab' => 'ಪಶ್ಚಿಮ ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಸಮಯ (ನೂಕ್)',
+        'America/Godthab' => 'ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಸಮಯ (ನೂಕ್)',
+        'America/Nuuk' => 'ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಸಮಯ (ನೂಕ್)',
         'America/Goose_Bay' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಗೂಸ್ ಬೇ)',
         'America/Grand_Turk' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಗ್ರ್ಯಾಂಡ್ ಟರ್ಕ್)',
         'America/Grenada' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಗ್ರೆನಾಡ)',
@@ -124,10 +132,12 @@ return [
         'America/Indiana/Vincennes' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ವಿನ್‌ಸೆನ್ನೀಸ್, ಇಂಡಿಯಾನಾ)',
         'America/Indiana/Winamac' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ವಿನಾಮ್ಯಾಕ್, ಇಂಡಿಯಾನಾ)',
         'America/Indianapolis' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಇಂಡಿಯಾನಾಪೊಲಿಸ್)',
+        'America/Indiana/Indianapolis' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಇಂಡಿಯಾನಾಪೊಲಿಸ್)',
         'America/Inuvik' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಇನುವಿಕ್)',
         'America/Iqaluit' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಈಕ್ವಾಲಿಟ್)',
         'America/Jamaica' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಜಮೈಕಾ)',
-        'America/Jujuy' => 'ಅರ್ಜೆಂಟಿನಾ ಸಮಯ (ಜುಜೈ)',
+        'America/Jujuy' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಜುಜೈ)',
+        'America/Argentina/Jujuy' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಜುಜೈ)',
         'America/Juneau' => 'ಅಲಾಸ್ಕಾ ಸಮಯ (ಜುನೇವ್)',
         'America/Kentucky/Monticello' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಮೊಂಟಿಸೆಲ್ಲೋ, ಕೆಂಟುಕಿ)',
         'America/Kralendijk' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಕ್ರೆಲೆಂಡಿಜ್ಕ್)',
@@ -135,6 +145,7 @@ return [
         'America/Lima' => 'ಪೆರು ಸಮಯ (ಲಿಮಾ)',
         'America/Los_Angeles' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೆಸಿಫಿಕ್ ಸಮಯ (ಲಾಸ್ ಏಂಜಲೀಸ್)',
         'America/Louisville' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಲೂಯೀಸ್‌ವಿಲ್ಲೆ)',
+        'America/Kentucky/Louisville' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಲೂಯೀಸ್‌ವಿಲ್ಲೆ)',
         'America/Lower_Princes' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಲೋವರ್ ಪ್ರಿನ್ಸಸ್ ಕ್ವಾರ್ಟರ್)',
         'America/Maceio' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಮೆಸೀಯೊ)',
         'America/Managua' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಮನಾಗುವಾ)',
@@ -143,7 +154,8 @@ return [
         'America/Martinique' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಮಾರ್ಟಿನಿಕ್)',
         'America/Matamoros' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಮಟಾಮೋರಸ್)',
         'America/Mazatlan' => 'ಮೆಕ್ಸಿಕನ್ ಪೆಸಿಫಿಕ್ ಸಮಯ (ಮಜಟ್ಲಾನ್)',
-        'America/Mendoza' => 'ಅರ್ಜೆಂಟಿನಾ ಸಮಯ (ಮೆಂಡೊಜಾ)',
+        'America/Mendoza' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಮೆಂಡೊಜಾ)',
+        'America/Argentina/Mendoza' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಮೆಂಡೊಜಾ)',
         'America/Menominee' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಮೆನೊಮಿನೀ)',
         'America/Merida' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಮೆರಿದಾ)',
         'America/Metlakatla' => 'ಅಲಾಸ್ಕಾ ಸಮಯ (ಮೆಟ್ಲಾಕಾಟ್ಲಾ)',
@@ -152,19 +164,16 @@ return [
         'America/Moncton' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಮಾಂಕ್ಟನ್)',
         'America/Monterrey' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಮಾಂಟೆರ್ರಿ)',
         'America/Montevideo' => 'ಉರುಗ್ವೇ ಸಮಯ (ಮಾಂಟಿವೀಡಿಯೊ)',
-        'America/Montreal' => 'ಕೆನಡಾ ಸಮಯ (Montreal)',
         'America/Montserrat' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಮಾಂಟ್‌ಸೆರೇಟ್)',
         'America/Nassau' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ನಸ್ಸೌವ್)',
         'America/New_York' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ನ್ಯೂಯಾರ್ಕ್)',
-        'America/Nipigon' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ನಿಪಿಗನ್)',
         'America/Nome' => 'ಅಲಾಸ್ಕಾ ಸಮಯ (ನೋಮ್)',
         'America/Noronha' => 'ಫೆರ್ನಾಂಡೋ ಡೆ ನೊರೊನ್ಹಾ ಸಮಯ',
         'America/North_Dakota/Beulah' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಬ್ಯೂಲಾ, ಉತ್ತರ ಡಕೊಟ)',
         'America/North_Dakota/Center' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಸೆಂಟರ್, ಉತ್ತರ ಡಕೊಟ)',
         'America/North_Dakota/New_Salem' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ನ್ಯೂ ಸಲೇಂ, ಉತ್ತರ ಡಕೊಟ)',
-        'America/Ojinaga' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಓಜಿನಾಗಾ)',
+        'America/Ojinaga' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಓಜಿನಾಗಾ)',
         'America/Panama' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಪನಾಮಾ)',
-        'America/Pangnirtung' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಪಂಗ್ನೀರ್‌ಟಂಗ್)',
         'America/Paramaribo' => 'ಸುರಿನೇಮ್ ಸಮಯ (ಪರಮಾರಿಬೋ)',
         'America/Phoenix' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಫಿನಿಕ್ಸ್)',
         'America/Port-au-Prince' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಪೋರ್ಟ್-ಒ-ಪ್ರಿನ್ಸ್)',
@@ -172,29 +181,26 @@ return [
         'America/Porto_Velho' => 'ಅಮೆಜಾನ್ ಸಮಯ (ಪೋರ್ಟೊ ವೆಲ್ಹೋ)',
         'America/Puerto_Rico' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಪ್ಯುರ್ಟೋ ರಿಕೊ)',
         'America/Punta_Arenas' => 'ಚಿಲಿ ಸಮಯ (ಪುಂತಾ ಅರೇನಾಸ್)',
-        'America/Rainy_River' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ರೈನಿ ರಿವರ್)',
         'America/Rankin_Inlet' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ರಾಂಕಿನ್ ಇನ್‌ಲೆಟ್)',
         'America/Recife' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ರೆಸಿಫಿ)',
         'America/Regina' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ರೆಜಿನಾ)',
         'America/Resolute' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ರೆಸೊಲ್ಯೂಟ್)',
         'America/Rio_Branco' => 'ಏಕರ್ ಸಮಯ (ರಿಯೋ ಬ್ರ್ಯಾಂಕೊ)',
-        'America/Santa_Isabel' => 'ವಾಯವ್ಯ ಮೆಕ್ಸಿಕೊ ಸಮಯ (ಸಾಂತಾ ಇಸಾಬೆಲ್)',
         'America/Santarem' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಸಾಂಟರೆಮ್)',
         'America/Santiago' => 'ಚಿಲಿ ಸಮಯ (ಸ್ಯಾಂಟಿಯಾಗೊ)',
         'America/Santo_Domingo' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸ್ಯಾಂಟೋ ಡೊಮಿಂಗೊ)',
         'America/Sao_Paulo' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಸಾವ್ ಪಾಲೊ)',
-        'America/Scoresbysund' => 'ಪೂರ್ವ ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಸಮಯ (ಇಟ್ಟೊಕ್ಕೊರ್ಟೂಮಿಯೈಟ್)',
+        'America/Scoresbysund' => 'ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಸಮಯ (ಇಟ್ಟೊಕ್ಕೊರ್ಟೂಮಿಯೈಟ್)',
         'America/Sitka' => 'ಅಲಾಸ್ಕಾ ಸಮಯ (ಸಿತ್ಕಾ)',
         'America/St_Barthelemy' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸೇಂಟ್ ಬಾರ್ತೆಲೆಮಿ)',
         'America/St_Johns' => 'ನ್ಯೂಫೌಂಡ್‌ಲ್ಯಾಂಡ್ ಸಮಯ (ಸೇಂಟ್ ಜಾನ್ಸ್)',
         'America/St_Kitts' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸೇಂಟ್ ಕಿಟ್ಸ್)',
         'America/St_Lucia' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸೇಂಟ್ ಲೂಸಿಯಾ)',
-        'America/St_Thomas' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸೆಂಟ್ ಥಾಮಸ್)',
+        'America/St_Thomas' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸೇಂಟ್ ಥಾಮಸ್)',
         'America/St_Vincent' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸೇಂಟ್ ವಿನ್ಸೆಂಟ್)',
         'America/Swift_Current' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಸ್ವಿಫ್ಟ್ ಕರೆಂಟ್)',
         'America/Tegucigalpa' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ತೆಗುಸಿಗಲ್ಪಾ)',
         'America/Thule' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಥೂಲೆ)',
-        'America/Thunder_Bay' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಥಂಡರ್ ಬೇ)',
         'America/Tijuana' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೆಸಿಫಿಕ್ ಸಮಯ (ತಿಜ್ವಾನಾ)',
         'America/Toronto' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಟೊರೊಂಟೋ)',
         'America/Tortola' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಟಾರ್ಟೊಲಾ)',
@@ -202,8 +208,7 @@ return [
         'America/Whitehorse' => 'ಯುಕಾನ್ ಸಮಯ (ವೈಟ್‌ಹಾರ್ಸ್)',
         'America/Winnipeg' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ವಿನ್ನಿಪೆಗ್)',
         'America/Yakutat' => 'ಅಲಾಸ್ಕಾ ಸಮಯ (ಯಾಕುಟಾಟ್)',
-        'America/Yellowknife' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಯೆಲ್ಲೋ‌ನೈಫ್)',
-        'Antarctica/Casey' => 'ಅಂಟಾರ್ಟಿಕಾ ಸಮಯ (ಕೇಸಿ)',
+        'Antarctica/Casey' => 'ಪಶ್ಚಿಮ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಕೇಸಿ)',
         'Antarctica/Davis' => 'ಡೇವಿಸ್ ಸಮಯ (ಡೇವೀಸ್)',
         'Antarctica/DumontDUrville' => 'ಡುಮಂಟ್-ಡಿ ಉರ್ವಿಲೆ ಸಮಯ',
         'Antarctica/Macquarie' => 'ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಮ್ಯಾಕ್ವೆರಿ)',
@@ -216,24 +221,24 @@ return [
         'Antarctica/Vostok' => 'ವೋಸ್ಟೊಕ್ ಸಮಯ (ವೋಸ್ಟೋಕ್)',
         'Arctic/Longyearbyen' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಲಾಂಗ್ಯೀರ್ಬೆನ್)',
         'Asia/Aden' => 'ಅರೇಬಿಯನ್ ಸಮಯ (ಏಡನ್)',
-        'Asia/Almaty' => 'ಪೂರ್ವ ಕಜಕಿಸ್ತಾನ್ ಸಮಯ (ಅಲ್ಮಾಟಿ)',
+        'Asia/Almaty' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಅಲ್ಮಾಟಿ)',
         'Asia/Amman' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಅಮ್ಮಾನ್)',
-        'Asia/Anadyr' => 'ಅನಡೀರ್‌ ಸಮಯ (ಅನದ್ಯರ್)',
-        'Asia/Aqtau' => 'ಪಶ್ಚಿಮ ಕಜಕಿಸ್ತಾನ್ ಸಮಯ (ಅಕ್ತಾವ್)',
-        'Asia/Aqtobe' => 'ಪಶ್ಚಿಮ ಕಜಕಿಸ್ತಾನ್ ಸಮಯ (ಅಕ್ಟೋಬೆ)',
+        'Asia/Anadyr' => 'ಪೆತ್ರೋಪಾವ್ಲೋಸ್ಕ್‌‌-ಕಮ್ಚತ್ಸ್‌ಕೀ ಸಮಯ (ಅನದ್ಯರ್)',
+        'Asia/Aqtau' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಅಕ್ತಾವ್)',
+        'Asia/Aqtobe' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಅಕ್ಟೋಬೆ)',
         'Asia/Ashgabat' => 'ತುರ್ಕ್‌ಮೇನಿಸ್ತಾನ್ ಸಮಯ (ಅಶ್ಗಬಾತ್)',
-        'Asia/Atyrau' => 'ಪಶ್ಚಿಮ ಕಜಕಿಸ್ತಾನ್ ಸಮಯ (ಅಟ್ರಾವ್)',
+        'Asia/Atyrau' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಅಟ್ರಾವ್)',
         'Asia/Baghdad' => 'ಅರೇಬಿಯನ್ ಸಮಯ (ಬಾಗ್ದಾದ್)',
         'Asia/Bahrain' => 'ಅರೇಬಿಯನ್ ಸಮಯ (ಬಹ್ರೇನ್)',
         'Asia/Baku' => 'ಅಜರ್ಬೈಜಾನ್ ಸಮಯ (ಬಕು)',
         'Asia/Bangkok' => 'ಇಂಡೊಚೈನಾ ಸಮಯ (ಬ್ಯಾಂಕಾಕ್)',
-        'Asia/Barnaul' => 'ರಷ್ಯಾ ಸಮಯ (ಬಾರ್ನೌಲ್)',
+        'Asia/Barnaul' => 'ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಸಮಯ (ಬಾರ್ನೌಲ್)',
         'Asia/Beirut' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಬೀರಟ್)',
         'Asia/Bishkek' => 'ಕಿರ್ಗಿಸ್ತಾನ್ ಸಮಯ (ಬಿಶ್ಕೆಕ್)',
         'Asia/Brunei' => 'ಬ್ರೂನಿ ದಾರುಸಲೆಮ್ ಸಮಯ',
         'Asia/Calcutta' => 'ಭಾರತೀಯ ಪ್ರಮಾಣಿತ ಸಮಯ (ಕೊಲ್ಕತ್ತಾ)',
+        'Asia/Kolkata' => 'ಭಾರತೀಯ ಪ್ರಮಾಣಿತ ಸಮಯ (ಕೊಲ್ಕತ್ತಾ)',
         'Asia/Chita' => 'ಯಾಕುಟ್ಸಕ್ ಸಮಯ (ಚಿಟ)',
-        'Asia/Choibalsan' => 'ಉಲಾನ್ ಬತೊರ್ ಸಮಯ (ಚೊಯ್‍ಬಾಲ್ಸನ್)',
         'Asia/Colombo' => 'ಭಾರತೀಯ ಪ್ರಮಾಣಿತ ಸಮಯ (ಕೊಲಂಬೊ)',
         'Asia/Damascus' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಡಮಾಸ್ಕಸ್)',
         'Asia/Dhaka' => 'ಬಾಂಗ್ಲಾದೇಶ ಸಮಯ (ಢಾಕಾ)',
@@ -253,6 +258,7 @@ return [
         'Asia/Kamchatka' => 'ಪೆತ್ರೋಪಾವ್ಲೋಸ್ಕ್‌‌-ಕಮ್ಚತ್ಸ್‌ಕೀ ಸಮಯ (ಕಂಚಟ್ಕ್)',
         'Asia/Karachi' => 'ಪಾಕಿಸ್ತಾನ ಸಮಯ (ಕರಾಚಿ)',
         'Asia/Katmandu' => 'ನೇಪಾಳ ಸಮಯ (ಕಠ್ಮಂಡು)',
+        'Asia/Kathmandu' => 'ನೇಪಾಳ ಸಮಯ (ಕಠ್ಮಂಡು)',
         'Asia/Khandyga' => 'ಯಾಕುಟ್ಸಕ್ ಸಮಯ (ಖಂಡ್ಯಾಗಾ)',
         'Asia/Krasnoyarsk' => 'ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಸಮಯ (ಕ್ರಾಸ್ನೊಯಾರ್ಸ್ಕ್)',
         'Asia/Kuala_Lumpur' => 'ಮಲೇಷಿಯಾ ಸಮಯ (ಕೌಲಾ ಲಂಪುರ)',
@@ -265,19 +271,21 @@ return [
         'Asia/Muscat' => 'ಗಲ್ಫ್ ಪ್ರಮಾಣಿತ ಸಮಯ (ಮಸ್ಕಟ್)',
         'Asia/Nicosia' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ನಿಕೋಸಿಯಾ)',
         'Asia/Novokuznetsk' => 'ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಸಮಯ (ನೋವೋಕುಜೆ)',
-        'Asia/Novosibirsk' => 'ನೊವೊಸಿಬಿರ್‌ಸ್ಕ್ ಸಮಯ (ನೊವೋಸಿಬಿಸ್ಕ್)',
+        'Asia/Novosibirsk' => 'ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಸಮಯ (ನೊವೋಸಿಬಿಸ್ಕ್)',
         'Asia/Omsk' => 'ಒಮಾಸ್ಕ್ ಸಮಯ (ಒಮ್ಸ್ಕ್)',
-        'Asia/Oral' => 'ಪಶ್ಚಿಮ ಕಜಕಿಸ್ತಾನ್ ಸಮಯ (ಒರಲ್)',
+        'Asia/Oral' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಒರಲ್)',
         'Asia/Phnom_Penh' => 'ಇಂಡೊಚೈನಾ ಸಮಯ (ನೋಮ್ ಪೆನ್)',
         'Asia/Pontianak' => 'ಪಶ್ಚಿಮ ಇಂಡೋನೇಷಿಯ ಸಮಯ (ಪೊಂಟಿಯಾನಕ್)',
         'Asia/Pyongyang' => 'ಕೊರಿಯನ್ ಸಮಯ (ಪ್ಯೊಂಗ್‍ಯಾಂಗ್)',
         'Asia/Qatar' => 'ಅರೇಬಿಯನ್ ಸಮಯ (ಖತಾರ್)',
-        'Asia/Qostanay' => 'ಪೂರ್ವ ಕಜಕಿಸ್ತಾನ್ ಸಮಯ (ಕೊಸ್ಟನಯ್)',
-        'Asia/Qyzylorda' => 'ಪಶ್ಚಿಮ ಕಜಕಿಸ್ತಾನ್ ಸಮಯ (ಕಿಜೈಲೋರ್ದ)',
+        'Asia/Qostanay' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಕೊಸ್ಟನಯ್)',
+        'Asia/Qyzylorda' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಕಿಜೈಲೋರ್ದ)',
         'Asia/Rangoon' => 'ಮ್ಯಾನ್ಮಾರ್ ಸಮಯ (ಯಾಂಗೊನ್)',
+        'Asia/Yangon' => 'ಮ್ಯಾನ್ಮಾರ್ ಸಮಯ (ಯಾಂಗೊನ್)',
         'Asia/Riyadh' => 'ಅರೇಬಿಯನ್ ಸಮಯ (ರಿಯಾದ್)',
         'Asia/Saigon' => 'ಇಂಡೊಚೈನಾ ಸಮಯ (ಹೊ ಚಿ ಮಿನ್ ಸಿಟಿ)',
-        'Asia/Sakhalin' => 'ಸ್ಯಾಕ್‌ಹಲಿನ್ ಸಮಯ (ಸಖಾಲಿನ್)',
+        'Asia/Ho_Chi_Minh' => 'ಇಂಡೊಚೈನಾ ಸಮಯ (ಹೊ ಚಿ ಮಿನ್ ಸಿಟಿ)',
+        'Asia/Sakhalin' => 'ಮಗಡಾನ್ ಸಮಯ (ಸಖಾಲಿನ್)',
         'Asia/Samarkand' => 'ಉಜ್ಬೇಕಿಸ್ತಾನ್ ಸಮಯ (ಸಮರಖಂಡ)',
         'Asia/Seoul' => 'ಕೊರಿಯನ್ ಸಮಯ (ಸಿಯೋಲ್)',
         'Asia/Shanghai' => 'ಚೀನಾ ಸಮಯ (ಶಾಂಘೈ)',
@@ -289,7 +297,7 @@ return [
         'Asia/Tehran' => 'ಇರಾನ್ ಸಮಯ (ತೆಹ್ರಾನ್)',
         'Asia/Thimphu' => 'ಭೂತಾನ್ ಸಮಯ (ಥಿಂಪು)',
         'Asia/Tokyo' => 'ಜಪಾನ್ ಸಮಯ (ಟೋಕಿಯೊ)',
-        'Asia/Tomsk' => 'ರಷ್ಯಾ ಸಮಯ (ಟೋಮ್‌ಸ್ಕ್)',
+        'Asia/Tomsk' => 'ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಸಮಯ (ಟೋಮ್‌ಸ್ಕ್)',
         'Asia/Ulaanbaatar' => 'ಉಲಾನ್ ಬತೊರ್ ಸಮಯ',
         'Asia/Urumqi' => 'ಚೀನಾ ಸಮಯ (ಉರುಮ್‍ಕಿ)',
         'Asia/Ust-Nera' => 'ವ್ಲಾಡಿವೋಸ್ಟೋಕ್ ಸಮಯ (ಉಸ್ತ್-ನೆರಾ)',
@@ -303,6 +311,7 @@ return [
         'Atlantic/Canary' => 'ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ (ಕ್ಯಾನರಿ)',
         'Atlantic/Cape_Verde' => 'ಕೇಪ್ ವರ್ಡ್ ಸಮಯ (ಕೇಪ್ ವೆರ್ಡ್)',
         'Atlantic/Faeroe' => 'ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ (ಫ್ಯಾರೊ)',
+        'Atlantic/Faroe' => 'ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ (ಫ್ಯಾರೊ)',
         'Atlantic/Madeira' => 'ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ (ಮೆಡಿರಾ)',
         'Atlantic/Reykjavik' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ರೈಕ್ಜಾವಿಕ್)',
         'Atlantic/South_Georgia' => 'ದಕ್ಷಿಣ ಜಾರ್ಜಿಯಾ ಸಮಯ',
@@ -311,7 +320,6 @@ return [
         'Australia/Adelaide' => 'ಕೇಂದ್ರ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಅಡಿಲೇಡ್)',
         'Australia/Brisbane' => 'ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಬ್ರಿಸ್ಬೇನ್‌)',
         'Australia/Broken_Hill' => 'ಕೇಂದ್ರ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಬ್ರೊಕನ್ ಹಿಲ್)',
-        'Australia/Currie' => 'ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಕರೀ)',
         'Australia/Darwin' => 'ಕೇಂದ್ರ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಡಾರ್ವಿನ್)',
         'Australia/Eucla' => 'ಆಸ್ಟ್ರೇಲಿಯಾದ ಕೇಂದ್ರ ಪಶ್ಚಿಮ ಸಮಯ (ಯುಕ್ಲಾ)',
         'Australia/Hobart' => 'ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಹೋಬಾರ್ಟ್‌)',
@@ -320,13 +328,11 @@ return [
         'Australia/Melbourne' => 'ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಮೆಲ್ಬರ್ನ್)',
         'Australia/Perth' => 'ಪಶ್ಚಿಮ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಪರ್ಥ್)',
         'Australia/Sydney' => 'ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಸಿಡ್ನಿ)',
-        'CST6CDT' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ',
-        'EST5EDT' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ',
         'Etc/GMT' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ',
         'Etc/UTC' => 'ಸಂಘಟಿತ ಸಾರ್ವತ್ರಿಕ ಸಮಯ',
         'Europe/Amsterdam' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಆಮ್‌ಸ್ಟೆರ್‌ಡ್ಯಾಂ)',
         'Europe/Andorra' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಅಂಡೋರಾ)',
-        'Europe/Astrakhan' => 'ಮಾಸ್ಕೋ ಸಮಯ (ಆಸ್ಟ್ರಾಖಾನ್)',
+        'Europe/Astrakhan' => 'ಸಮರ ಸಮಯ (ಆಸ್ಟ್ರಾಖಾನ್)',
         'Europe/Athens' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಅಥೆನ್ಸ್)',
         'Europe/Belgrade' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಬೆಲ್‌ಗ್ರೇಡ್)',
         'Europe/Berlin' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಬರ್ಲಿನ್)',
@@ -342,11 +348,12 @@ return [
         'Europe/Guernsey' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಗ್ಯುರ್ನ್‍ಸೆ)',
         'Europe/Helsinki' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಹೆಲ್ಸಿಂಕಿ)',
         'Europe/Isle_of_Man' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಐಲ್ ಆಫ್ ಮ್ಯಾನ್)',
-        'Europe/Istanbul' => 'ಟರ್ಕಿ ಸಮಯ (ಇಸ್ತಾನ್‌ಬುಲ್)',
+        'Europe/Istanbul' => 'ತುರ್ಕಿಯೆ ಸಮಯ (ಇಸ್ತಾನ್‌ಬುಲ್)',
         'Europe/Jersey' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಜೆರ್ಸಿ)',
         'Europe/Kaliningrad' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಕಲಿನಿನ್‌ಗ್ರಾಡ್)',
         'Europe/Kiev' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಕಿವ್)',
-        'Europe/Kirov' => 'ರಷ್ಯಾ ಸಮಯ (ಕಿರಾವ್)',
+        'Europe/Kyiv' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಕಿವ್)',
+        'Europe/Kirov' => 'ಮಾಸ್ಕೋ ಸಮಯ (ಕಿರಾವ್)',
         'Europe/Lisbon' => 'ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ (ಲಿಸ್ಬನ್)',
         'Europe/Ljubljana' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಲ್ಯೂಬ್ಲ್ಯಾನಾ)',
         'Europe/London' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಲಂಡನ್)',
@@ -366,23 +373,21 @@ return [
         'Europe/Samara' => 'ಸಮರ ಸಮಯ',
         'Europe/San_Marino' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಸ್ಯಾನ್ ಮರೀನೊ)',
         'Europe/Sarajevo' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಸರಯೇವೊ)',
-        'Europe/Saratov' => 'ಮಾಸ್ಕೋ ಸಮಯ (ಸರಾಟೋವ್)',
+        'Europe/Saratov' => 'ಸಮರ ಸಮಯ (ಸರಾಟೋವ್)',
         'Europe/Simferopol' => 'ಮಾಸ್ಕೋ ಸಮಯ (ಸಿಮ್ಫೆರೋಪೋಲ್)',
         'Europe/Skopje' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಸ್ಕಾಪಿಯಾ)',
         'Europe/Sofia' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಸೋಫಿಯಾ)',
         'Europe/Stockholm' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಸ್ಟಾಕ್‍ಹೋಮ್)',
         'Europe/Tallinn' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಟ್ಯಾಲಿನ್)',
         'Europe/Tirane' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಟಿರಾನೆ)',
-        'Europe/Ulyanovsk' => 'ಮಾಸ್ಕೋ ಸಮಯ (ಉಲ್ಯಾನೊವಸ್ಕ್)',
-        'Europe/Uzhgorod' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಉಜ್‌ಗೊರೊದ್)',
+        'Europe/Ulyanovsk' => 'ಸಮರ ಸಮಯ (ಉಲ್ಯಾನೊವಸ್ಕ್)',
         'Europe/Vaduz' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ವಡೂಜ್)',
         'Europe/Vatican' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ವ್ಯಾಟಿಕನ್)',
         'Europe/Vienna' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ವಿಯೆನ್ನಾ)',
         'Europe/Vilnius' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ವಿಲ್ನಿಯಸ್)',
-        'Europe/Volgograd' => 'ವೋಲ್ಗೋಗಾರ್ಡ್ ಸಮಯ (ವೊಲ್ಗೊಗ್ರಾಡ್)',
+        'Europe/Volgograd' => 'ಮಾಸ್ಕೋ ಸಮಯ (ವೊಲ್ಗೊಗ್ರಾಡ್)',
         'Europe/Warsaw' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ವಾರ್ಸಾ)',
         'Europe/Zagreb' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಜಾಗ್ರೆಬ್‌)',
-        'Europe/Zaporozhye' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಜಾಪರೀಝಿಯಾ)',
         'Europe/Zurich' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಜ್ಯೂರಿಕ್)',
         'Indian/Antananarivo' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಅಂಟಾನನಾರಿವೊ)',
         'Indian/Chagos' => 'ಹಿಂದೂ ಮಹಾಸಾಗರ ಸಮಯ (ಚಾಗೊಸ್)',
@@ -395,15 +400,14 @@ return [
         'Indian/Mauritius' => 'ಮಾರಿಷಸ್ ಸಮಯ',
         'Indian/Mayotte' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಮಯೊಟ್ಟೆ)',
         'Indian/Reunion' => 'ರಿಯೂನಿಯನ್ ಸಮಯ (ರೀಯೂನಿಯನ್)',
-        'MST7MDT' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ',
-        'PST8PDT' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೆಸಿಫಿಕ್ ಸಮಯ',
         'Pacific/Apia' => 'ಅಪಿಯಾ ಸಮಯ',
         'Pacific/Auckland' => 'ನ್ಯೂಜಿಲ್ಯಾಂಡ್ ಸಮಯ (ಆಕ್ ಲ್ಯಾಂಡ್)',
         'Pacific/Bougainville' => 'ಪಪುವಾ ನ್ಯೂ ಗಿನಿಯಾ ಸಮಯ (ಬೌಗೆನ್‍ವಿಲ್ಲೆ)',
         'Pacific/Chatham' => 'ಚಥಾಮ್ ಸಮಯ',
         'Pacific/Easter' => 'ಈಸ್ಟರ್ ದ್ವೀಪ ಸಮಯ',
         'Pacific/Efate' => 'ವನೌತು ಸಮಯ (ಇಫೇಟ್)',
-        'Pacific/Enderbury' => 'ಫಿನಿಕ್ಸ್ ದ್ವೀಪಗಳ ಸಮಯ (ಎಂಡರ್ಬರಿ)',
+        'Pacific/Enderbury' => 'ಫಿನಿಕ್ಸ್ ದ್ವೀಪಗಳ ಸಮಯ (ಕ್ಯಾಂಟನ್ ಐಲ್ಯಾಂಡ್)',
+        'Pacific/Kanton' => 'ಫಿನಿಕ್ಸ್ ದ್ವೀಪಗಳ ಸಮಯ (ಕ್ಯಾಂಟನ್ ಐಲ್ಯಾಂಡ್)',
         'Pacific/Fakaofo' => 'ಟೊಕೆಲಾವ್ ಸಮಯ (ಫಕೋಫೋ)',
         'Pacific/Fiji' => 'ಫಿಜಿ ಸಮಯ',
         'Pacific/Funafuti' => 'ತುವಾಲು ಸಮಯ (ಫುನಾಫುಟಿ)',
@@ -411,8 +415,7 @@ return [
         'Pacific/Gambier' => 'ಗ್ಯಾಂಬಿಯರ್ ಸಮಯ',
         'Pacific/Guadalcanal' => 'ಸಾಲಮನ್ ದ್ವೀಪಗಳ ಸಮಯ (ಗ್ವಾಡಲ್ಕೆನಾಲ್)',
         'Pacific/Guam' => 'ಚಮೋರೋ ಪ್ರಮಾಣಿತ ಸಮಯ (ಗ್ವಾಮ್)',
-        'Pacific/Honolulu' => 'ಹವಾಯಿ-ಅಲ್ಯುಟಿಯನ್ ಸಮಯ (ಹೊನಲುಲು)',
-        'Pacific/Johnston' => 'ಹವಾಯಿ-ಅಲ್ಯುಟಿಯನ್ ಸಮಯ (ಜಾನ್‌ಸ್ಟನ್)',
+        'Pacific/Honolulu' => 'ಹವಾಯಿ-ಅಲ್ಯುಟಿಯನ್ ಪ್ರಮಾಣಿತ ಸಮಯ (ಹೊನಲುಲು)',
         'Pacific/Kiritimati' => 'ಲೈನ್ ದ್ವೀಪಗಳ ಸಮಯ (ಕಿರಿತಿಮತಿ)',
         'Pacific/Kosrae' => 'ಕೊಸರೆ ಸಮಯ (ಕೋಸ್ರೆ)',
         'Pacific/Kwajalein' => 'ಮಾರ್ಷಲ್ ದ್ವೀಪಗಳ ಸಮಯ (ಕ್ವಾಜಲೇನ್)',
@@ -427,6 +430,7 @@ return [
         'Pacific/Palau' => 'ಪಾಲಾವ್ ಸಮಯ',
         'Pacific/Pitcairn' => 'ಪಿಟ್‌ಕೈರ್ನ್ ಸಮಯ',
         'Pacific/Ponape' => 'ಪೊನಾಪೆ ಸಮಯ (ಪೋನ್‌ಪೆ)',
+        'Pacific/Pohnpei' => 'ಪೊನಾಪೆ ಸಮಯ (ಪೋನ್‌ಪೆ)',
         'Pacific/Port_Moresby' => 'ಪಪುವಾ ನ್ಯೂ ಗಿನಿಯಾ ಸಮಯ (ಪೋರ್ಟ್ ಮೋರಿಸ್‌ಬೈ)',
         'Pacific/Rarotonga' => 'ಕುಕ್ ದ್ವೀಪಗಳ ಸಮಯ (ರರೋಟೋಂಗಾ)',
         'Pacific/Saipan' => 'ಚಮೋರೋ ಪ್ರಮಾಣಿತ ಸಮಯ (ಸೈಪನ್)',
@@ -434,9 +438,9 @@ return [
         'Pacific/Tarawa' => 'ಗಿಲ್ಬರ್ಟ್ ದ್ವೀಪಗಳ ಸಮಯ (ತರಾವಾ)',
         'Pacific/Tongatapu' => 'ಟೊಂಗಾ ಸಮಯ (ಟೊಂಗಾಟಾಪು)',
         'Pacific/Truk' => 'ಚುಕ್ ಸಮಯ',
+        'Pacific/Chuuk' => 'ಚುಕ್ ಸಮಯ',
         'Pacific/Wake' => 'ವೇಕ್ ದ್ವೀಪ ಸಮಯ',
         'Pacific/Wallis' => 'ವ್ಯಾಲೀಸ್ ಮತ್ತು ಫ್ಯುಟುನಾ ಸಮಯ (ವ್ಯಾಲಿಸ್)',
     ],
-    'Meta' => [
-    ],
+    'Meta' => [],
 ];
